@@ -11,32 +11,32 @@ Boxer::Part::Reclass - software component as a reclass node or class
 use v5.14;
 use utf8;
 use strictures 2;
-use version;
 use Role::Commons -all;
+use namespace::autoclean 0.16;
 use autodie;
 
 use Moo;
-extends 'Boxer::Part';
+use MooX::StrictConstructor;
+extends qw(Boxer::Part);
+
 use Types::Standard qw(Str Maybe ArrayRef HashRef);
 use Types::TypeTiny qw(StringLike);
 
-use namespace::autoclean 0.16;
-
 =head1 VERSION
 
-Version v1.2.0
+Version v1.4.0
 
 =cut
 
-our $VERSION = version->declare("v1.2.0");
+our $VERSION = "v1.4.0";
 
 =head1 DESCRIPTION
 
 Outside the box is a World of software,
 consisting of parts.
 
-B<Boxer::Part::Reclass::Node> represents a part of a <Boxer::World>,
-represented as a B<reclass> node or class.
+B<Boxer::Part::Reclass> represents a part of a L<Boxer::World>
+structured as a B<reclass> node or class.
 
 =head1 SEE ALSO
 
